# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class BatchQueueDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'description': 'str',
        'cluster_name': 'str',
        'max_runtime': 'int',
        'max_allocation': 'int',
        'reported_avail_tasks': 'int',
        'reported_max_tasks': 'int',
        'sla': 'SLA',
        'maintenance_mode': 'bool',
        'resource_config': 'ClusterNodeConfig'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'cluster_name': 'cluster_name',
        'max_runtime': 'max_runtime',
        'max_allocation': 'max_allocation',
        'reported_avail_tasks': 'reported_avail_tasks',
        'reported_max_tasks': 'reported_max_tasks',
        'sla': 'sla',
        'maintenance_mode': 'maintenance_mode',
        'resource_config': 'resource_config'
    }

    def __init__(self, id=None, name=None, description=None, cluster_name=None, max_runtime=None, max_allocation=None, reported_avail_tasks=None, reported_max_tasks=None, sla=None, maintenance_mode=None, resource_config=None, local_vars_configuration=None):  # noqa: E501
        """BatchQueueDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._description = None
        self._cluster_name = None
        self._max_runtime = None
        self._max_allocation = None
        self._reported_avail_tasks = None
        self._reported_max_tasks = None
        self._sla = None
        self._maintenance_mode = None
        self._resource_config = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        self.description = description
        if cluster_name is not None:
            self.cluster_name = cluster_name
        if max_runtime is not None:
            self.max_runtime = max_runtime
        if max_allocation is not None:
            self.max_allocation = max_allocation
        self.reported_avail_tasks = reported_avail_tasks
        self.reported_max_tasks = reported_max_tasks
        self.sla = sla
        if maintenance_mode is not None:
            self.maintenance_mode = maintenance_mode
        self.resource_config = resource_config

    @property
    def id(self):
        """Gets the id of this BatchQueueDetails.  # noqa: E501


        :return: The id of this BatchQueueDetails.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BatchQueueDetails.


        :param id: The id of this BatchQueueDetails.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this BatchQueueDetails.  # noqa: E501


        :return: The name of this BatchQueueDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BatchQueueDetails.


        :param name: The name of this BatchQueueDetails.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this BatchQueueDetails.  # noqa: E501


        :return: The description of this BatchQueueDetails.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BatchQueueDetails.


        :param description: The description of this BatchQueueDetails.  # noqa: E501
        :type description: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 1000):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `1000`")  # noqa: E501

        self._description = description

    @property
    def cluster_name(self):
        """Gets the cluster_name of this BatchQueueDetails.  # noqa: E501


        :return: The cluster_name of this BatchQueueDetails.  # noqa: E501
        :rtype: str
        """
        return self._cluster_name

    @cluster_name.setter
    def cluster_name(self, cluster_name):
        """Sets the cluster_name of this BatchQueueDetails.


        :param cluster_name: The cluster_name of this BatchQueueDetails.  # noqa: E501
        :type cluster_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                cluster_name is not None and len(cluster_name) > 100):
            raise ValueError("Invalid value for `cluster_name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cluster_name is not None and len(cluster_name) < 1):
            raise ValueError("Invalid value for `cluster_name`, length must be greater than or equal to `1`")  # noqa: E501

        self._cluster_name = cluster_name

    @property
    def max_runtime(self):
        """Gets the max_runtime of this BatchQueueDetails.  # noqa: E501


        :return: The max_runtime of this BatchQueueDetails.  # noqa: E501
        :rtype: int
        """
        return self._max_runtime

    @max_runtime.setter
    def max_runtime(self, max_runtime):
        """Sets the max_runtime of this BatchQueueDetails.


        :param max_runtime: The max_runtime of this BatchQueueDetails.  # noqa: E501
        :type max_runtime: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_runtime is not None and max_runtime > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `max_runtime`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_runtime is not None and max_runtime < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_runtime`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_runtime = max_runtime

    @property
    def max_allocation(self):
        """Gets the max_allocation of this BatchQueueDetails.  # noqa: E501


        :return: The max_allocation of this BatchQueueDetails.  # noqa: E501
        :rtype: int
        """
        return self._max_allocation

    @max_allocation.setter
    def max_allocation(self, max_allocation):
        """Sets the max_allocation of this BatchQueueDetails.


        :param max_allocation: The max_allocation of this BatchQueueDetails.  # noqa: E501
        :type max_allocation: int
        """
        if (self.local_vars_configuration.client_side_validation and
                max_allocation is not None and max_allocation > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `max_allocation`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_allocation is not None and max_allocation < 0):  # noqa: E501
            raise ValueError("Invalid value for `max_allocation`, must be a value greater than or equal to `0`")  # noqa: E501

        self._max_allocation = max_allocation

    @property
    def reported_avail_tasks(self):
        """Gets the reported_avail_tasks of this BatchQueueDetails.  # noqa: E501


        :return: The reported_avail_tasks of this BatchQueueDetails.  # noqa: E501
        :rtype: int
        """
        return self._reported_avail_tasks

    @reported_avail_tasks.setter
    def reported_avail_tasks(self, reported_avail_tasks):
        """Sets the reported_avail_tasks of this BatchQueueDetails.


        :param reported_avail_tasks: The reported_avail_tasks of this BatchQueueDetails.  # noqa: E501
        :type reported_avail_tasks: int
        """
        if (self.local_vars_configuration.client_side_validation and
                reported_avail_tasks is not None and reported_avail_tasks > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `reported_avail_tasks`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                reported_avail_tasks is not None and reported_avail_tasks < 0):  # noqa: E501
            raise ValueError("Invalid value for `reported_avail_tasks`, must be a value greater than or equal to `0`")  # noqa: E501

        self._reported_avail_tasks = reported_avail_tasks

    @property
    def reported_max_tasks(self):
        """Gets the reported_max_tasks of this BatchQueueDetails.  # noqa: E501


        :return: The reported_max_tasks of this BatchQueueDetails.  # noqa: E501
        :rtype: int
        """
        return self._reported_max_tasks

    @reported_max_tasks.setter
    def reported_max_tasks(self, reported_max_tasks):
        """Sets the reported_max_tasks of this BatchQueueDetails.


        :param reported_max_tasks: The reported_max_tasks of this BatchQueueDetails.  # noqa: E501
        :type reported_max_tasks: int
        """
        if (self.local_vars_configuration.client_side_validation and
                reported_max_tasks is not None and reported_max_tasks > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `reported_max_tasks`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                reported_max_tasks is not None and reported_max_tasks < 0):  # noqa: E501
            raise ValueError("Invalid value for `reported_max_tasks`, must be a value greater than or equal to `0`")  # noqa: E501

        self._reported_max_tasks = reported_max_tasks

    @property
    def sla(self):
        """Gets the sla of this BatchQueueDetails.  # noqa: E501


        :return: The sla of this BatchQueueDetails.  # noqa: E501
        :rtype: SLA
        """
        return self._sla

    @sla.setter
    def sla(self, sla):
        """Sets the sla of this BatchQueueDetails.


        :param sla: The sla of this BatchQueueDetails.  # noqa: E501
        :type sla: SLA
        """
        if self.local_vars_configuration.client_side_validation and sla is None:  # noqa: E501
            raise ValueError("Invalid value for `sla`, must not be `None`")  # noqa: E501

        self._sla = sla

    @property
    def maintenance_mode(self):
        """Gets the maintenance_mode of this BatchQueueDetails.  # noqa: E501


        :return: The maintenance_mode of this BatchQueueDetails.  # noqa: E501
        :rtype: bool
        """
        return self._maintenance_mode

    @maintenance_mode.setter
    def maintenance_mode(self, maintenance_mode):
        """Sets the maintenance_mode of this BatchQueueDetails.


        :param maintenance_mode: The maintenance_mode of this BatchQueueDetails.  # noqa: E501
        :type maintenance_mode: bool
        """

        self._maintenance_mode = maintenance_mode

    @property
    def resource_config(self):
        """Gets the resource_config of this BatchQueueDetails.  # noqa: E501


        :return: The resource_config of this BatchQueueDetails.  # noqa: E501
        :rtype: ClusterNodeConfig
        """
        return self._resource_config

    @resource_config.setter
    def resource_config(self, resource_config):
        """Sets the resource_config of this BatchQueueDetails.


        :param resource_config: The resource_config of this BatchQueueDetails.  # noqa: E501
        :type resource_config: ClusterNodeConfig
        """
        if self.local_vars_configuration.client_side_validation and resource_config is None:  # noqa: E501
            raise ValueError("Invalid value for `resource_config`, must not be `None`")  # noqa: E501

        self._resource_config = resource_config

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchQueueDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BatchQueueDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from epiccore.models.accelerator_config import AcceleratorConfig
from epiccore.models.ansys_license import AnsysLicense
from epiccore.models.batch_application_details import BatchApplicationDetails
from epiccore.models.batch_application_list import BatchApplicationList
from epiccore.models.batch_application_version_details import BatchApplicationVersionDetails
from epiccore.models.batch_queue_details import BatchQueueDetails
from epiccore.models.budget import Budget
from epiccore.models.cluster_node_config import ClusterNodeConfig
from epiccore.models.cost import Cost
from epiccore.models.cost_threshold import CostThreshold
from epiccore.models.current_spend import CurrentSpend
from epiccore.models.data_spec import DataSpec
from epiccore.models.desktop_instance import DesktopInstance
from epiccore.models.desktop_node_app import DesktopNodeApp
from epiccore.models.desktop_node_app_summary import DesktopNodeAppSummary
from epiccore.models.desktop_node_application_version import DesktopNodeApplicationVersion
from epiccore.models.desktop_node_application_version_summary import DesktopNodeApplicationVersionSummary
from epiccore.models.desktop_node_connection_type import DesktopNodeConnectionType
from epiccore.models.desktop_node_launch_spec import DesktopNodeLaunchSpec
from epiccore.models.desktop_node_quote import DesktopNodeQuote
from epiccore.models.desktop_node_type import DesktopNodeType
from epiccore.models.discount import Discount
from epiccore.models.folder import Folder
from epiccore.models.folder_details import FolderDetails
from epiccore.models.iaas_cost import IaasCost
from epiccore.models.inline_response200 import InlineResponse200
from epiccore.models.inline_response2001 import InlineResponse2001
from epiccore.models.inline_response20010 import InlineResponse20010
from epiccore.models.inline_response2002 import InlineResponse2002
from epiccore.models.inline_response2003 import InlineResponse2003
from epiccore.models.inline_response2004 import InlineResponse2004
from epiccore.models.inline_response2005 import InlineResponse2005
from epiccore.models.inline_response2006 import InlineResponse2006
from epiccore.models.inline_response2007 import InlineResponse2007
from epiccore.models.inline_response2008 import InlineResponse2008
from epiccore.models.inline_response2009 import InlineResponse2009
from epiccore.models.job import Job
from epiccore.models.job_app_options import JobAppOptions
from epiccore.models.job_array_spec import JobArraySpec
from epiccore.models.job_auth import JobAuth
from epiccore.models.job_auth_status import JobAuthStatus
from epiccore.models.job_cluster_spec import JobClusterSpec
from epiccore.models.job_configuration import JobConfiguration
from epiccore.models.job_data_binding import JobDataBinding
from epiccore.models.job_log import JobLog
from epiccore.models.job_quote import JobQuote
from epiccore.models.job_spec import JobSpec
from epiccore.models.job_step import JobStep
from epiccore.models.job_step_details import JobStepDetails
from epiccore.models.job_summary import JobSummary
from epiccore.models.job_task_spec import JobTaskSpec
from epiccore.models.license import License
from epiccore.models.limit import Limit
from epiccore.models.limits import Limits
from epiccore.models.max_limit import MaxLimit
from epiccore.models.monthly_limit import MonthlyLimit
from epiccore.models.price_quote import PriceQuote
from epiccore.models.product_name import ProductName
from epiccore.models.profile_summary import ProfileSummary
from epiccore.models.project import Project
from epiccore.models.project_details import ProjectDetails
from epiccore.models.sla import SLA
from epiccore.models.service_charge import ServiceCharge
from epiccore.models.software_cost import SoftwareCost
from epiccore.models.spend_limit import SpendLimit
from epiccore.models.task_quote import TaskQuote
from epiccore.models.tax import Tax
from epiccore.models.team import Team
from epiccore.models.team_details import TeamDetails
from epiccore.models.team_select import TeamSelect
from epiccore.models.total import Total
from epiccore.models.total1 import Total1
from epiccore.models.user_name import UserName
from epiccore.models.zenotech_license import ZenotechLicense



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class JobDataBinding(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'spec': 'JobSpec',
        'app_options': 'object',
        'cluster': 'JobClusterSpec',
        'input_data': 'DataSpec'
    }

    attribute_map = {
        'name': 'name',
        'spec': 'spec',
        'app_options': 'app_options',
        'cluster': 'cluster',
        'input_data': 'input_data'
    }

    def __init__(self, name=None, spec=None, app_options=None, cluster=None, input_data=None, local_vars_configuration=None):  # noqa: E501
        """JobDataBinding - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._spec = None
        self._app_options = None
        self._cluster = None
        self._input_data = None
        self.discriminator = None

        self.name = name
        self.spec = spec
        self.app_options = app_options
        self.cluster = cluster
        self.input_data = input_data

    @property
    def name(self):
        """Gets the name of this JobDataBinding.  # noqa: E501

        Name for this job  # noqa: E501

        :return: The name of this JobDataBinding.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobDataBinding.

        Name for this job  # noqa: E501

        :param name: The name of this JobDataBinding.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def spec(self):
        """Gets the spec of this JobDataBinding.  # noqa: E501


        :return: The spec of this JobDataBinding.  # noqa: E501
        :rtype: JobSpec
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this JobDataBinding.


        :param spec: The spec of this JobDataBinding.  # noqa: E501
        :type spec: JobSpec
        """
        if self.local_vars_configuration.client_side_validation and spec is None:  # noqa: E501
            raise ValueError("Invalid value for `spec`, must not be `None`")  # noqa: E501

        self._spec = spec

    @property
    def app_options(self):
        """Gets the app_options of this JobDataBinding.  # noqa: E501

        Application specific options  # noqa: E501

        :return: The app_options of this JobDataBinding.  # noqa: E501
        :rtype: object
        """
        return self._app_options

    @app_options.setter
    def app_options(self, app_options):
        """Sets the app_options of this JobDataBinding.

        Application specific options  # noqa: E501

        :param app_options: The app_options of this JobDataBinding.  # noqa: E501
        :type app_options: object
        """
        if self.local_vars_configuration.client_side_validation and app_options is None:  # noqa: E501
            raise ValueError("Invalid value for `app_options`, must not be `None`")  # noqa: E501

        self._app_options = app_options

    @property
    def cluster(self):
        """Gets the cluster of this JobDataBinding.  # noqa: E501


        :return: The cluster of this JobDataBinding.  # noqa: E501
        :rtype: JobClusterSpec
        """
        return self._cluster

    @cluster.setter
    def cluster(self, cluster):
        """Sets the cluster of this JobDataBinding.


        :param cluster: The cluster of this JobDataBinding.  # noqa: E501
        :type cluster: JobClusterSpec
        """
        if self.local_vars_configuration.client_side_validation and cluster is None:  # noqa: E501
            raise ValueError("Invalid value for `cluster`, must not be `None`")  # noqa: E501

        self._cluster = cluster

    @property
    def input_data(self):
        """Gets the input_data of this JobDataBinding.  # noqa: E501


        :return: The input_data of this JobDataBinding.  # noqa: E501
        :rtype: DataSpec
        """
        return self._input_data

    @input_data.setter
    def input_data(self, input_data):
        """Sets the input_data of this JobDataBinding.


        :param input_data: The input_data of this JobDataBinding.  # noqa: E501
        :type input_data: DataSpec
        """
        if self.local_vars_configuration.client_side_validation and input_data is None:  # noqa: E501
            raise ValueError("Invalid value for `input_data`, must not be `None`")  # noqa: E501

        self._input_data = input_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDataBinding):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobDataBinding):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class JobAuth(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'enabled': 'bool',
        'all_jobs': 'bool',
        'cost_threshold': 'CostThreshold',
        'description_str': 'str'
    }

    attribute_map = {
        'enabled': 'enabled',
        'all_jobs': 'all_jobs',
        'cost_threshold': 'cost_threshold',
        'description_str': 'description_str'
    }

    def __init__(self, enabled=False, all_jobs=False, cost_threshold=None, description_str=None, local_vars_configuration=None):  # noqa: E501
        """JobAuth - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._enabled = None
        self._all_jobs = None
        self._cost_threshold = None
        self._description_str = None
        self.discriminator = None

        if enabled is not None:
            self.enabled = enabled
        if all_jobs is not None:
            self.all_jobs = all_jobs
        if cost_threshold is not None:
            self.cost_threshold = cost_threshold
        if description_str is not None:
            self.description_str = description_str

    @property
    def enabled(self):
        """Gets the enabled of this JobAuth.  # noqa: E501

        Is job authorisation enabled?  # noqa: E501

        :return: The enabled of this JobAuth.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this JobAuth.

        Is job authorisation enabled?  # noqa: E501

        :param enabled: The enabled of this JobAuth.  # noqa: E501
        :type enabled: bool
        """

        self._enabled = enabled

    @property
    def all_jobs(self):
        """Gets the all_jobs of this JobAuth.  # noqa: E501

        If authorisation is enabled, then does it apply to all jobs?  # noqa: E501

        :return: The all_jobs of this JobAuth.  # noqa: E501
        :rtype: bool
        """
        return self._all_jobs

    @all_jobs.setter
    def all_jobs(self, all_jobs):
        """Sets the all_jobs of this JobAuth.

        If authorisation is enabled, then does it apply to all jobs?  # noqa: E501

        :param all_jobs: The all_jobs of this JobAuth.  # noqa: E501
        :type all_jobs: bool
        """

        self._all_jobs = all_jobs

    @property
    def cost_threshold(self):
        """Gets the cost_threshold of this JobAuth.  # noqa: E501


        :return: The cost_threshold of this JobAuth.  # noqa: E501
        :rtype: CostThreshold
        """
        return self._cost_threshold

    @cost_threshold.setter
    def cost_threshold(self, cost_threshold):
        """Sets the cost_threshold of this JobAuth.


        :param cost_threshold: The cost_threshold of this JobAuth.  # noqa: E501
        :type cost_threshold: CostThreshold
        """

        self._cost_threshold = cost_threshold

    @property
    def description_str(self):
        """Gets the description_str of this JobAuth.  # noqa: E501

        A user readable description of the state of the job authorisation criteria  # noqa: E501

        :return: The description_str of this JobAuth.  # noqa: E501
        :rtype: str
        """
        return self._description_str

    @description_str.setter
    def description_str(self, description_str):
        """Sets the description_str of this JobAuth.

        A user readable description of the state of the job authorisation criteria  # noqa: E501

        :param description_str: The description_str of this JobAuth.  # noqa: E501
        :type description_str: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description_str is not None and len(description_str) > 30):
            raise ValueError("Invalid value for `description_str`, length must be less than or equal to `30`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description_str is not None and len(description_str) < 1):
            raise ValueError("Invalid value for `description_str`, length must be greater than or equal to `1`")  # noqa: E501

        self._description_str = description_str

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobAuth):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobAuth):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class JobSummary(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'app': 'str',
        'cost': 'str',
        'submitted_by': 'str',
        'submitted_at': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'app': 'app',
        'cost': 'cost',
        'submitted_by': 'submitted_by',
        'submitted_at': 'submitted_at'
    }

    def __init__(self, id=None, name=None, app=None, cost=None, submitted_by=None, submitted_at=None, local_vars_configuration=None):  # noqa: E501
        """JobSummary - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._app = None
        self._cost = None
        self._submitted_by = None
        self._submitted_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if app is not None:
            self.app = app
        if cost is not None:
            self.cost = cost
        if submitted_by is not None:
            self.submitted_by = submitted_by
        if submitted_at is not None:
            self.submitted_at = submitted_at

    @property
    def id(self):
        """Gets the id of this JobSummary.  # noqa: E501

        The ID for this job  # noqa: E501

        :return: The id of this JobSummary.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobSummary.

        The ID for this job  # noqa: E501

        :param id: The id of this JobSummary.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this JobSummary.  # noqa: E501

        Name of this job  # noqa: E501

        :return: The name of this JobSummary.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobSummary.

        Name of this job  # noqa: E501

        :param name: The name of this JobSummary.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def app(self):
        """Gets the app of this JobSummary.  # noqa: E501

        Name of the application that this job uses  # noqa: E501

        :return: The app of this JobSummary.  # noqa: E501
        :rtype: str
        """
        return self._app

    @app.setter
    def app(self, app):
        """Sets the app of this JobSummary.

        Name of the application that this job uses  # noqa: E501

        :param app: The app of this JobSummary.  # noqa: E501
        :type app: str
        """
        if (self.local_vars_configuration.client_side_validation and
                app is not None and len(app) > 30):
            raise ValueError("Invalid value for `app`, length must be less than or equal to `30`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                app is not None and len(app) < 1):
            raise ValueError("Invalid value for `app`, length must be greater than or equal to `1`")  # noqa: E501

        self._app = app

    @property
    def cost(self):
        """Gets the cost of this JobSummary.  # noqa: E501

        Maximum cost for running this job  # noqa: E501

        :return: The cost of this JobSummary.  # noqa: E501
        :rtype: str
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """Sets the cost of this JobSummary.

        Maximum cost for running this job  # noqa: E501

        :param cost: The cost of this JobSummary.  # noqa: E501
        :type cost: str
        """
        if (self.local_vars_configuration.client_side_validation and
                cost is not None and len(cost) > 30):
            raise ValueError("Invalid value for `cost`, length must be less than or equal to `30`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cost is not None and len(cost) < 1):
            raise ValueError("Invalid value for `cost`, length must be greater than or equal to `1`")  # noqa: E501

        self._cost = cost

    @property
    def submitted_by(self):
        """Gets the submitted_by of this JobSummary.  # noqa: E501

        Name of the user who submitted this job  # noqa: E501

        :return: The submitted_by of this JobSummary.  # noqa: E501
        :rtype: str
        """
        return self._submitted_by

    @submitted_by.setter
    def submitted_by(self, submitted_by):
        """Sets the submitted_by of this JobSummary.

        Name of the user who submitted this job  # noqa: E501

        :param submitted_by: The submitted_by of this JobSummary.  # noqa: E501
        :type submitted_by: str
        """

        self._submitted_by = submitted_by

    @property
    def submitted_at(self):
        """Gets the submitted_at of this JobSummary.  # noqa: E501

        Date at which this job was submitted  # noqa: E501

        :return: The submitted_at of this JobSummary.  # noqa: E501
        :rtype: str
        """
        return self._submitted_at

    @submitted_at.setter
    def submitted_at(self, submitted_at):
        """Sets the submitted_at of this JobSummary.

        Date at which this job was submitted  # noqa: E501

        :param submitted_at: The submitted_at of this JobSummary.  # noqa: E501
        :type submitted_at: str
        """

        self._submitted_at = submitted_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobSummary):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobSummary):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class Job(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'app': 'str',
        'app_options': 'object',
        'application_version': 'int',
        'cost': 'str',
        'status': 'str',
        'submitted_by': 'str',
        'submitted_at': 'str',
        'finished': 'bool',
        'resource': 'BatchQueueDetails',
        'project': 'int',
        'invoice_reference': 'str',
        'config': 'JobConfiguration',
        'job_steps': 'list[JobStep]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'app': 'app',
        'app_options': 'app_options',
        'application_version': 'application_version',
        'cost': 'cost',
        'status': 'status',
        'submitted_by': 'submitted_by',
        'submitted_at': 'submitted_at',
        'finished': 'finished',
        'resource': 'resource',
        'project': 'project',
        'invoice_reference': 'invoice_reference',
        'config': 'config',
        'job_steps': 'job_steps'
    }

    def __init__(self, id=None, name=None, app=None, app_options=None, application_version=None, cost=None, status=None, submitted_by=None, submitted_at=None, finished=None, resource=None, project=None, invoice_reference=None, config=None, job_steps=None, local_vars_configuration=None):  # noqa: E501
        """Job - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._app = None
        self._app_options = None
        self._application_version = None
        self._cost = None
        self._status = None
        self._submitted_by = None
        self._submitted_at = None
        self._finished = None
        self._resource = None
        self._project = None
        self._invoice_reference = None
        self._config = None
        self._job_steps = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if app is not None:
            self.app = app
        if app_options is not None:
            self.app_options = app_options
        if application_version is not None:
            self.application_version = application_version
        if cost is not None:
            self.cost = cost
        if status is not None:
            self.status = status
        if submitted_by is not None:
            self.submitted_by = submitted_by
        if submitted_at is not None:
            self.submitted_at = submitted_at
        if finished is not None:
            self.finished = finished
        if resource is not None:
            self.resource = resource
        if project is not None:
            self.project = project
        if invoice_reference is not None:
            self.invoice_reference = invoice_reference
        if config is not None:
            self.config = config
        if job_steps is not None:
            self.job_steps = job_steps

    @property
    def id(self):
        """Gets the id of this Job.  # noqa: E501

        The ID for this job  # noqa: E501

        :return: The id of this Job.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Job.

        The ID for this job  # noqa: E501

        :param id: The id of this Job.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this Job.  # noqa: E501

        Name of this job  # noqa: E501

        :return: The name of this Job.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Job.

        Name of this job  # noqa: E501

        :param name: The name of this Job.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def app(self):
        """Gets the app of this Job.  # noqa: E501

        Name of the application that this job uses  # noqa: E501

        :return: The app of this Job.  # noqa: E501
        :rtype: str
        """
        return self._app

    @app.setter
    def app(self, app):
        """Sets the app of this Job.

        Name of the application that this job uses  # noqa: E501

        :param app: The app of this Job.  # noqa: E501
        :type app: str
        """
        if (self.local_vars_configuration.client_side_validation and
                app is not None and len(app) > 30):
            raise ValueError("Invalid value for `app`, length must be less than or equal to `30`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                app is not None and len(app) < 1):
            raise ValueError("Invalid value for `app`, length must be greater than or equal to `1`")  # noqa: E501

        self._app = app

    @property
    def app_options(self):
        """Gets the app_options of this Job.  # noqa: E501

        Job app options  # noqa: E501

        :return: The app_options of this Job.  # noqa: E501
        :rtype: object
        """
        return self._app_options

    @app_options.setter
    def app_options(self, app_options):
        """Sets the app_options of this Job.

        Job app options  # noqa: E501

        :param app_options: The app_options of this Job.  # noqa: E501
        :type app_options: object
        """

        self._app_options = app_options

    @property
    def application_version(self):
        """Gets the application_version of this Job.  # noqa: E501

        Application version ID  # noqa: E501

        :return: The application_version of this Job.  # noqa: E501
        :rtype: int
        """
        return self._application_version

    @application_version.setter
    def application_version(self, application_version):
        """Sets the application_version of this Job.

        Application version ID  # noqa: E501

        :param application_version: The application_version of this Job.  # noqa: E501
        :type application_version: int
        """
        if (self.local_vars_configuration.client_side_validation and
                application_version is not None and application_version < 1):  # noqa: E501
            raise ValueError("Invalid value for `application_version`, must be a value greater than or equal to `1`")  # noqa: E501

        self._application_version = application_version

    @property
    def cost(self):
        """Gets the cost of this Job.  # noqa: E501

        Maximum cost for running this job  # noqa: E501

        :return: The cost of this Job.  # noqa: E501
        :rtype: str
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """Sets the cost of this Job.

        Maximum cost for running this job  # noqa: E501

        :param cost: The cost of this Job.  # noqa: E501
        :type cost: str
        """
        if (self.local_vars_configuration.client_side_validation and
                cost is not None and len(cost) > 30):
            raise ValueError("Invalid value for `cost`, length must be less than or equal to `30`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cost is not None and len(cost) < 1):
            raise ValueError("Invalid value for `cost`, length must be greater than or equal to `1`")  # noqa: E501

        self._cost = cost

    @property
    def status(self):
        """Gets the status of this Job.  # noqa: E501

        Current status of this job  # noqa: E501

        :return: The status of this Job.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Job.

        Current status of this job  # noqa: E501

        :param status: The status of this Job.  # noqa: E501
        :type status: str
        """
        if (self.local_vars_configuration.client_side_validation and
                status is not None and len(status) > 100):
            raise ValueError("Invalid value for `status`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                status is not None and len(status) < 1):
            raise ValueError("Invalid value for `status`, length must be greater than or equal to `1`")  # noqa: E501

        self._status = status

    @property
    def submitted_by(self):
        """Gets the submitted_by of this Job.  # noqa: E501

        Name of the user who submitted this job  # noqa: E501

        :return: The submitted_by of this Job.  # noqa: E501
        :rtype: str
        """
        return self._submitted_by

    @submitted_by.setter
    def submitted_by(self, submitted_by):
        """Sets the submitted_by of this Job.

        Name of the user who submitted this job  # noqa: E501

        :param submitted_by: The submitted_by of this Job.  # noqa: E501
        :type submitted_by: str
        """

        self._submitted_by = submitted_by

    @property
    def submitted_at(self):
        """Gets the submitted_at of this Job.  # noqa: E501

        Date at which this job was submitted  # noqa: E501

        :return: The submitted_at of this Job.  # noqa: E501
        :rtype: str
        """
        return self._submitted_at

    @submitted_at.setter
    def submitted_at(self, submitted_at):
        """Sets the submitted_at of this Job.

        Date at which this job was submitted  # noqa: E501

        :param submitted_at: The submitted_at of this Job.  # noqa: E501
        :type submitted_at: str
        """

        self._submitted_at = submitted_at

    @property
    def finished(self):
        """Gets the finished of this Job.  # noqa: E501

        Has this job finished?  # noqa: E501

        :return: The finished of this Job.  # noqa: E501
        :rtype: bool
        """
        return self._finished

    @finished.setter
    def finished(self, finished):
        """Sets the finished of this Job.

        Has this job finished?  # noqa: E501

        :param finished: The finished of this Job.  # noqa: E501
        :type finished: bool
        """

        self._finished = finished

    @property
    def resource(self):
        """Gets the resource of this Job.  # noqa: E501


        :return: The resource of this Job.  # noqa: E501
        :rtype: BatchQueueDetails
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this Job.


        :param resource: The resource of this Job.  # noqa: E501
        :type resource: BatchQueueDetails
        """

        self._resource = resource

    @property
    def project(self):
        """Gets the project of this Job.  # noqa: E501

        Project ID to bill this job against  # noqa: E501

        :return: The project of this Job.  # noqa: E501
        :rtype: int
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this Job.

        Project ID to bill this job against  # noqa: E501

        :param project: The project of this Job.  # noqa: E501
        :type project: int
        """
        if (self.local_vars_configuration.client_side_validation and
                project is not None and project < 1):  # noqa: E501
            raise ValueError("Invalid value for `project`, must be a value greater than or equal to `1`")  # noqa: E501

        self._project = project

    @property
    def invoice_reference(self):
        """Gets the invoice_reference of this Job.  # noqa: E501

        Invoice reference - this text will appear on the monthly invoice against this jobs charges  # noqa: E501

        :return: The invoice_reference of this Job.  # noqa: E501
        :rtype: str
        """
        return self._invoice_reference

    @invoice_reference.setter
    def invoice_reference(self, invoice_reference):
        """Sets the invoice_reference of this Job.

        Invoice reference - this text will appear on the monthly invoice against this jobs charges  # noqa: E501

        :param invoice_reference: The invoice_reference of this Job.  # noqa: E501
        :type invoice_reference: str
        """
        if (self.local_vars_configuration.client_side_validation and
                invoice_reference is not None and len(invoice_reference) > 100):
            raise ValueError("Invalid value for `invoice_reference`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                invoice_reference is not None and len(invoice_reference) < 1):
            raise ValueError("Invalid value for `invoice_reference`, length must be greater than or equal to `1`")  # noqa: E501

        self._invoice_reference = invoice_reference

    @property
    def config(self):
        """Gets the config of this Job.  # noqa: E501


        :return: The config of this Job.  # noqa: E501
        :rtype: JobConfiguration
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this Job.


        :param config: The config of this Job.  # noqa: E501
        :type config: JobConfiguration
        """

        self._config = config

    @property
    def job_steps(self):
        """Gets the job_steps of this Job.  # noqa: E501

        The job steps associated with this Job  # noqa: E501

        :return: The job_steps of this Job.  # noqa: E501
        :rtype: list[JobStep]
        """
        return self._job_steps

    @job_steps.setter
    def job_steps(self, job_steps):
        """Sets the job_steps of this Job.

        The job steps associated with this Job  # noqa: E501

        :param job_steps: The job_steps of this Job.  # noqa: E501
        :type job_steps: list[JobStep]
        """

        self._job_steps = job_steps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Job):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Job):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class JobLog(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'stdout': 'str',
        'stderr': 'str',
        'app': 'str',
        'last_update': 'str'
    }

    attribute_map = {
        'stdout': 'stdout',
        'stderr': 'stderr',
        'app': 'app',
        'last_update': 'last_update'
    }

    def __init__(self, stdout=None, stderr=None, app=None, last_update=None, local_vars_configuration=None):  # noqa: E501
        """JobLog - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._stdout = None
        self._stderr = None
        self._app = None
        self._last_update = None
        self.discriminator = None

        if stdout is not None:
            self.stdout = stdout
        if stderr is not None:
            self.stderr = stderr
        if app is not None:
            self.app = app
        if last_update is not None:
            self.last_update = last_update

    @property
    def stdout(self):
        """Gets the stdout of this JobLog.  # noqa: E501


        :return: The stdout of this JobLog.  # noqa: E501
        :rtype: str
        """
        return self._stdout

    @stdout.setter
    def stdout(self, stdout):
        """Sets the stdout of this JobLog.


        :param stdout: The stdout of this JobLog.  # noqa: E501
        :type stdout: str
        """

        self._stdout = stdout

    @property
    def stderr(self):
        """Gets the stderr of this JobLog.  # noqa: E501


        :return: The stderr of this JobLog.  # noqa: E501
        :rtype: str
        """
        return self._stderr

    @stderr.setter
    def stderr(self, stderr):
        """Sets the stderr of this JobLog.


        :param stderr: The stderr of this JobLog.  # noqa: E501
        :type stderr: str
        """

        self._stderr = stderr

    @property
    def app(self):
        """Gets the app of this JobLog.  # noqa: E501


        :return: The app of this JobLog.  # noqa: E501
        :rtype: str
        """
        return self._app

    @app.setter
    def app(self, app):
        """Sets the app of this JobLog.


        :param app: The app of this JobLog.  # noqa: E501
        :type app: str
        """

        self._app = app

    @property
    def last_update(self):
        """Gets the last_update of this JobLog.  # noqa: E501

        Last time the logs were updated  # noqa: E501

        :return: The last_update of this JobLog.  # noqa: E501
        :rtype: str
        """
        return self._last_update

    @last_update.setter
    def last_update(self, last_update):
        """Sets the last_update of this JobLog.

        Last time the logs were updated  # noqa: E501

        :param last_update: The last_update of this JobLog.  # noqa: E501
        :type last_update: str
        """

        self._last_update = last_update

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobLog):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobLog):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class AcceleratorConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'acc_class': 'str',
        'quantity': 'int',
        'description': 'str'
    }

    attribute_map = {
        'name': 'name',
        'acc_class': 'acc_class',
        'quantity': 'quantity',
        'description': 'description'
    }

    def __init__(self, name=None, acc_class=None, quantity=None, description=None, local_vars_configuration=None):  # noqa: E501
        """AcceleratorConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._acc_class = None
        self._quantity = None
        self._description = None
        self.discriminator = None

        self.name = name
        self.acc_class = acc_class
        if quantity is not None:
            self.quantity = quantity
        self.description = description

    @property
    def name(self):
        """Gets the name of this AcceleratorConfig.  # noqa: E501


        :return: The name of this AcceleratorConfig.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AcceleratorConfig.


        :param name: The name of this AcceleratorConfig.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def acc_class(self):
        """Gets the acc_class of this AcceleratorConfig.  # noqa: E501


        :return: The acc_class of this AcceleratorConfig.  # noqa: E501
        :rtype: str
        """
        return self._acc_class

    @acc_class.setter
    def acc_class(self, acc_class):
        """Sets the acc_class of this AcceleratorConfig.


        :param acc_class: The acc_class of this AcceleratorConfig.  # noqa: E501
        :type acc_class: str
        """
        if self.local_vars_configuration.client_side_validation and acc_class is None:  # noqa: E501
            raise ValueError("Invalid value for `acc_class`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                acc_class is not None and len(acc_class) > 100):
            raise ValueError("Invalid value for `acc_class`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                acc_class is not None and len(acc_class) < 1):
            raise ValueError("Invalid value for `acc_class`, length must be greater than or equal to `1`")  # noqa: E501

        self._acc_class = acc_class

    @property
    def quantity(self):
        """Gets the quantity of this AcceleratorConfig.  # noqa: E501


        :return: The quantity of this AcceleratorConfig.  # noqa: E501
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this AcceleratorConfig.


        :param quantity: The quantity of this AcceleratorConfig.  # noqa: E501
        :type quantity: int
        """
        if (self.local_vars_configuration.client_side_validation and
                quantity is not None and quantity > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                quantity is not None and quantity < -2147483648):  # noqa: E501
            raise ValueError("Invalid value for `quantity`, must be a value greater than or equal to `-2147483648`")  # noqa: E501

        self._quantity = quantity

    @property
    def description(self):
        """Gets the description of this AcceleratorConfig.  # noqa: E501


        :return: The description of this AcceleratorConfig.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AcceleratorConfig.


        :param description: The description of this AcceleratorConfig.  # noqa: E501
        :type description: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 255):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `255`")  # noqa: E501

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AcceleratorConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AcceleratorConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class JobArraySpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'config': 'JobConfiguration',
        'jobs': 'list[JobDataBinding]',
        'common_data': 'DataSpec'
    }

    attribute_map = {
        'name': 'name',
        'config': 'config',
        'jobs': 'jobs',
        'common_data': 'common_data'
    }

    def __init__(self, name='Job Array', config=None, jobs=None, common_data=None, local_vars_configuration=None):  # noqa: E501
        """JobArraySpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._config = None
        self._jobs = None
        self._common_data = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.config = config
        self.jobs = jobs
        if common_data is not None:
            self.common_data = common_data

    @property
    def name(self):
        """Gets the name of this JobArraySpec.  # noqa: E501

        Name of job array - only required for more than one job  # noqa: E501

        :return: The name of this JobArraySpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobArraySpec.

        Name of job array - only required for more than one job  # noqa: E501

        :param name: The name of this JobArraySpec.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def config(self):
        """Gets the config of this JobArraySpec.  # noqa: E501


        :return: The config of this JobArraySpec.  # noqa: E501
        :rtype: JobConfiguration
        """
        return self._config

    @config.setter
    def config(self, config):
        """Sets the config of this JobArraySpec.


        :param config: The config of this JobArraySpec.  # noqa: E501
        :type config: JobConfiguration
        """
        if self.local_vars_configuration.client_side_validation and config is None:  # noqa: E501
            raise ValueError("Invalid value for `config`, must not be `None`")  # noqa: E501

        self._config = config

    @property
    def jobs(self):
        """Gets the jobs of this JobArraySpec.  # noqa: E501

        List of job specs to launch  # noqa: E501

        :return: The jobs of this JobArraySpec.  # noqa: E501
        :rtype: list[JobDataBinding]
        """
        return self._jobs

    @jobs.setter
    def jobs(self, jobs):
        """Sets the jobs of this JobArraySpec.

        List of job specs to launch  # noqa: E501

        :param jobs: The jobs of this JobArraySpec.  # noqa: E501
        :type jobs: list[JobDataBinding]
        """
        if self.local_vars_configuration.client_side_validation and jobs is None:  # noqa: E501
            raise ValueError("Invalid value for `jobs`, must not be `None`")  # noqa: E501

        self._jobs = jobs

    @property
    def common_data(self):
        """Gets the common_data of this JobArraySpec.  # noqa: E501


        :return: The common_data of this JobArraySpec.  # noqa: E501
        :rtype: DataSpec
        """
        return self._common_data

    @common_data.setter
    def common_data(self, common_data):
        """Sets the common_data of this JobArraySpec.


        :param common_data: The common_data of this JobArraySpec.  # noqa: E501
        :type common_data: DataSpec
        """

        self._common_data = common_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobArraySpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobArraySpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class JobSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'application_version': 'int',
        'project': 'int',
        'tasks': 'list[JobTaskSpec]'
    }

    attribute_map = {
        'application_version': 'application_version',
        'project': 'project',
        'tasks': 'tasks'
    }

    def __init__(self, application_version=None, project=None, tasks=None, local_vars_configuration=None):  # noqa: E501
        """JobSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._application_version = None
        self._project = None
        self._tasks = None
        self.discriminator = None

        self.application_version = application_version
        if project is not None:
            self.project = project
        self.tasks = tasks

    @property
    def application_version(self):
        """Gets the application_version of this JobSpec.  # noqa: E501

        ID of the application_version to launch. Valid values are obtained from the catalog/applications/ endpoint  # noqa: E501

        :return: The application_version of this JobSpec.  # noqa: E501
        :rtype: int
        """
        return self._application_version

    @application_version.setter
    def application_version(self, application_version):
        """Sets the application_version of this JobSpec.

        ID of the application_version to launch. Valid values are obtained from the catalog/applications/ endpoint  # noqa: E501

        :param application_version: The application_version of this JobSpec.  # noqa: E501
        :type application_version: int
        """
        if self.local_vars_configuration.client_side_validation and application_version is None:  # noqa: E501
            raise ValueError("Invalid value for `application_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_version is not None and application_version < 1):  # noqa: E501
            raise ValueError("Invalid value for `application_version`, must be a value greater than or equal to `1`")  # noqa: E501

        self._application_version = application_version

    @property
    def project(self):
        """Gets the project of this JobSpec.  # noqa: E501

        Project ID to bill this job against  # noqa: E501

        :return: The project of this JobSpec.  # noqa: E501
        :rtype: int
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this JobSpec.

        Project ID to bill this job against  # noqa: E501

        :param project: The project of this JobSpec.  # noqa: E501
        :type project: int
        """
        if (self.local_vars_configuration.client_side_validation and
                project is not None and project < -1):  # noqa: E501
            raise ValueError("Invalid value for `project`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._project = project

    @property
    def tasks(self):
        """Gets the tasks of this JobSpec.  # noqa: E501

        List of task definitions that make up this job  # noqa: E501

        :return: The tasks of this JobSpec.  # noqa: E501
        :rtype: list[JobTaskSpec]
        """
        return self._tasks

    @tasks.setter
    def tasks(self, tasks):
        """Sets the tasks of this JobSpec.

        List of task definitions that make up this job  # noqa: E501

        :param tasks: The tasks of this JobSpec.  # noqa: E501
        :type tasks: list[JobTaskSpec]
        """
        if self.local_vars_configuration.client_side_validation and tasks is None:  # noqa: E501
            raise ValueError("Invalid value for `tasks`, must not be `None`")  # noqa: E501

        self._tasks = tasks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class TaskQuote(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'reference': 'str',
        'queue_id': 'int',
        'iaas_cost': 'IaasCost',
        'software_cost': 'SoftwareCost',
        'service_charge': 'ServiceCharge',
        'discount': 'Discount',
        'tax': 'Tax',
        'total': 'Total1'
    }

    attribute_map = {
        'reference': 'reference',
        'queue_id': 'queue_id',
        'iaas_cost': 'iaas_cost',
        'software_cost': 'software_cost',
        'service_charge': 'service_charge',
        'discount': 'discount',
        'tax': 'tax',
        'total': 'total'
    }

    def __init__(self, reference=None, queue_id=None, iaas_cost=None, software_cost=None, service_charge=None, discount=None, tax=None, total=None, local_vars_configuration=None):  # noqa: E501
        """TaskQuote - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._reference = None
        self._queue_id = None
        self._iaas_cost = None
        self._software_cost = None
        self._service_charge = None
        self._discount = None
        self._tax = None
        self._total = None
        self.discriminator = None

        if reference is not None:
            self.reference = reference
        if queue_id is not None:
            self.queue_id = queue_id
        if iaas_cost is not None:
            self.iaas_cost = iaas_cost
        if software_cost is not None:
            self.software_cost = software_cost
        if service_charge is not None:
            self.service_charge = service_charge
        if discount is not None:
            self.discount = discount
        if tax is not None:
            self.tax = tax
        if total is not None:
            self.total = total

    @property
    def reference(self):
        """Gets the reference of this TaskQuote.  # noqa: E501

        The reference given in the quote request, to help you identify this task.  # noqa: E501

        :return: The reference of this TaskQuote.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this TaskQuote.

        The reference given in the quote request, to help you identify this task.  # noqa: E501

        :param reference: The reference of this TaskQuote.  # noqa: E501
        :type reference: str
        """
        if (self.local_vars_configuration.client_side_validation and
                reference is not None and len(reference) > 25):
            raise ValueError("Invalid value for `reference`, length must be less than or equal to `25`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                reference is not None and len(reference) < 1):
            raise ValueError("Invalid value for `reference`, length must be greater than or equal to `1`")  # noqa: E501

        self._reference = reference

    @property
    def queue_id(self):
        """Gets the queue_id of this TaskQuote.  # noqa: E501

        The ID of the queue for this quote  # noqa: E501

        :return: The queue_id of this TaskQuote.  # noqa: E501
        :rtype: int
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """Sets the queue_id of this TaskQuote.

        The ID of the queue for this quote  # noqa: E501

        :param queue_id: The queue_id of this TaskQuote.  # noqa: E501
        :type queue_id: int
        """
        if (self.local_vars_configuration.client_side_validation and
                queue_id is not None and queue_id < -1):  # noqa: E501
            raise ValueError("Invalid value for `queue_id`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._queue_id = queue_id

    @property
    def iaas_cost(self):
        """Gets the iaas_cost of this TaskQuote.  # noqa: E501


        :return: The iaas_cost of this TaskQuote.  # noqa: E501
        :rtype: IaasCost
        """
        return self._iaas_cost

    @iaas_cost.setter
    def iaas_cost(self, iaas_cost):
        """Sets the iaas_cost of this TaskQuote.


        :param iaas_cost: The iaas_cost of this TaskQuote.  # noqa: E501
        :type iaas_cost: IaasCost
        """

        self._iaas_cost = iaas_cost

    @property
    def software_cost(self):
        """Gets the software_cost of this TaskQuote.  # noqa: E501


        :return: The software_cost of this TaskQuote.  # noqa: E501
        :rtype: SoftwareCost
        """
        return self._software_cost

    @software_cost.setter
    def software_cost(self, software_cost):
        """Sets the software_cost of this TaskQuote.


        :param software_cost: The software_cost of this TaskQuote.  # noqa: E501
        :type software_cost: SoftwareCost
        """

        self._software_cost = software_cost

    @property
    def service_charge(self):
        """Gets the service_charge of this TaskQuote.  # noqa: E501


        :return: The service_charge of this TaskQuote.  # noqa: E501
        :rtype: ServiceCharge
        """
        return self._service_charge

    @service_charge.setter
    def service_charge(self, service_charge):
        """Sets the service_charge of this TaskQuote.


        :param service_charge: The service_charge of this TaskQuote.  # noqa: E501
        :type service_charge: ServiceCharge
        """

        self._service_charge = service_charge

    @property
    def discount(self):
        """Gets the discount of this TaskQuote.  # noqa: E501


        :return: The discount of this TaskQuote.  # noqa: E501
        :rtype: Discount
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """Sets the discount of this TaskQuote.


        :param discount: The discount of this TaskQuote.  # noqa: E501
        :type discount: Discount
        """

        self._discount = discount

    @property
    def tax(self):
        """Gets the tax of this TaskQuote.  # noqa: E501


        :return: The tax of this TaskQuote.  # noqa: E501
        :rtype: Tax
        """
        return self._tax

    @tax.setter
    def tax(self, tax):
        """Sets the tax of this TaskQuote.


        :param tax: The tax of this TaskQuote.  # noqa: E501
        :type tax: Tax
        """

        self._tax = tax

    @property
    def total(self):
        """Gets the total of this TaskQuote.  # noqa: E501


        :return: The total of this TaskQuote.  # noqa: E501
        :rtype: Total1
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this TaskQuote.


        :param total: The total of this TaskQuote.  # noqa: E501
        :type total: Total1
        """

        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TaskQuote):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TaskQuote):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class DesktopNodeLaunchSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'application_version': 'int',
        'node_type': 'int',
        'connection_type': 'int',
        'runtime': 'int',
        'secure_ip': 'bool',
        'ip_address': 'str',
        'invoice_reference': 'str',
        'data_path': 'DataSpec',
        'mount_type': 'str',
        'project': 'int'
    }

    attribute_map = {
        'application_version': 'application_version',
        'node_type': 'node_type',
        'connection_type': 'connection_type',
        'runtime': 'runtime',
        'secure_ip': 'secure_ip',
        'ip_address': 'ip_address',
        'invoice_reference': 'invoice_reference',
        'data_path': 'data_path',
        'mount_type': 'mount_type',
        'project': 'project'
    }

    def __init__(self, application_version=None, node_type=None, connection_type=None, runtime=None, secure_ip=False, ip_address=None, invoice_reference=None, data_path=None, mount_type=None, project=None, local_vars_configuration=None):  # noqa: E501
        """DesktopNodeLaunchSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._application_version = None
        self._node_type = None
        self._connection_type = None
        self._runtime = None
        self._secure_ip = None
        self._ip_address = None
        self._invoice_reference = None
        self._data_path = None
        self._mount_type = None
        self._project = None
        self.discriminator = None

        self.application_version = application_version
        self.node_type = node_type
        self.connection_type = connection_type
        self.runtime = runtime
        if secure_ip is not None:
            self.secure_ip = secure_ip
        if ip_address is not None:
            self.ip_address = ip_address
        if invoice_reference is not None:
            self.invoice_reference = invoice_reference
        self.data_path = data_path
        self.mount_type = mount_type
        if project is not None:
            self.project = project

    @property
    def application_version(self):
        """Gets the application_version of this DesktopNodeLaunchSpec.  # noqa: E501

        ID of the application_version to launch. Valid values are obtained from the catalog/desktop/ endpoint  # noqa: E501

        :return: The application_version of this DesktopNodeLaunchSpec.  # noqa: E501
        :rtype: int
        """
        return self._application_version

    @application_version.setter
    def application_version(self, application_version):
        """Sets the application_version of this DesktopNodeLaunchSpec.

        ID of the application_version to launch. Valid values are obtained from the catalog/desktop/ endpoint  # noqa: E501

        :param application_version: The application_version of this DesktopNodeLaunchSpec.  # noqa: E501
        :type application_version: int
        """
        if self.local_vars_configuration.client_side_validation and application_version is None:  # noqa: E501
            raise ValueError("Invalid value for `application_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_version is not None and application_version < 1):  # noqa: E501
            raise ValueError("Invalid value for `application_version`, must be a value greater than or equal to `1`")  # noqa: E501

        self._application_version = application_version

    @property
    def node_type(self):
        """Gets the node_type of this DesktopNodeLaunchSpec.  # noqa: E501

        ID of the node_type. Valid values are obtained from the catalog/desktop/ endpoint  # noqa: E501

        :return: The node_type of this DesktopNodeLaunchSpec.  # noqa: E501
        :rtype: int
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """Sets the node_type of this DesktopNodeLaunchSpec.

        ID of the node_type. Valid values are obtained from the catalog/desktop/ endpoint  # noqa: E501

        :param node_type: The node_type of this DesktopNodeLaunchSpec.  # noqa: E501
        :type node_type: int
        """
        if self.local_vars_configuration.client_side_validation and node_type is None:  # noqa: E501
            raise ValueError("Invalid value for `node_type`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                node_type is not None and node_type < 1):  # noqa: E501
            raise ValueError("Invalid value for `node_type`, must be a value greater than or equal to `1`")  # noqa: E501

        self._node_type = node_type

    @property
    def connection_type(self):
        """Gets the connection_type of this DesktopNodeLaunchSpec.  # noqa: E501

        The connection type to use for the Desktop  # noqa: E501

        :return: The connection_type of this DesktopNodeLaunchSpec.  # noqa: E501
        :rtype: int
        """
        return self._connection_type

    @connection_type.setter
    def connection_type(self, connection_type):
        """Sets the connection_type of this DesktopNodeLaunchSpec.

        The connection type to use for the Desktop  # noqa: E501

        :param connection_type: The connection_type of this DesktopNodeLaunchSpec.  # noqa: E501
        :type connection_type: int
        """
        if self.local_vars_configuration.client_side_validation and connection_type is None:  # noqa: E501
            raise ValueError("Invalid value for `connection_type`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_type is not None and connection_type < 1):  # noqa: E501
            raise ValueError("Invalid value for `connection_type`, must be a value greater than or equal to `1`")  # noqa: E501

        self._connection_type = connection_type

    @property
    def runtime(self):
        """Gets the runtime of this DesktopNodeLaunchSpec.  # noqa: E501

        Runtime in hours to run this desktop node for. This is the maximum runtime as the viz node can be stopped earlier and you will only be charged for the elapsed time  # noqa: E501

        :return: The runtime of this DesktopNodeLaunchSpec.  # noqa: E501
        :rtype: int
        """
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):
        """Sets the runtime of this DesktopNodeLaunchSpec.

        Runtime in hours to run this desktop node for. This is the maximum runtime as the viz node can be stopped earlier and you will only be charged for the elapsed time  # noqa: E501

        :param runtime: The runtime of this DesktopNodeLaunchSpec.  # noqa: E501
        :type runtime: int
        """
        if self.local_vars_configuration.client_side_validation and runtime is None:  # noqa: E501
            raise ValueError("Invalid value for `runtime`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                runtime is not None and runtime < 1):  # noqa: E501
            raise ValueError("Invalid value for `runtime`, must be a value greater than or equal to `1`")  # noqa: E501

        self._runtime = runtime

    @property
    def secure_ip(self):
        """Gets the secure_ip of this DesktopNodeLaunchSpec.  # noqa: E501

        Should we restrict which IPs can connect to this node?  # noqa: E501

        :return: The secure_ip of this DesktopNodeLaunchSpec.  # noqa: E501
        :rtype: bool
        """
        return self._secure_ip

    @secure_ip.setter
    def secure_ip(self, secure_ip):
        """Sets the secure_ip of this DesktopNodeLaunchSpec.

        Should we restrict which IPs can connect to this node?  # noqa: E501

        :param secure_ip: The secure_ip of this DesktopNodeLaunchSpec.  # noqa: E501
        :type secure_ip: bool
        """

        self._secure_ip = secure_ip

    @property
    def ip_address(self):
        """Gets the ip_address of this DesktopNodeLaunchSpec.  # noqa: E501

        IPv4 Address to restrict connections to this node from  # noqa: E501

        :return: The ip_address of this DesktopNodeLaunchSpec.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this DesktopNodeLaunchSpec.

        IPv4 Address to restrict connections to this node from  # noqa: E501

        :param ip_address: The ip_address of this DesktopNodeLaunchSpec.  # noqa: E501
        :type ip_address: str
        """
        if (self.local_vars_configuration.client_side_validation and
                ip_address is not None and len(ip_address) < 1):
            raise ValueError("Invalid value for `ip_address`, length must be greater than or equal to `1`")  # noqa: E501

        self._ip_address = ip_address

    @property
    def invoice_reference(self):
        """Gets the invoice_reference of this DesktopNodeLaunchSpec.  # noqa: E501

        Invoice reference - this text will appear on the monthly invoice against this nodes charges  # noqa: E501

        :return: The invoice_reference of this DesktopNodeLaunchSpec.  # noqa: E501
        :rtype: str
        """
        return self._invoice_reference

    @invoice_reference.setter
    def invoice_reference(self, invoice_reference):
        """Sets the invoice_reference of this DesktopNodeLaunchSpec.

        Invoice reference - this text will appear on the monthly invoice against this nodes charges  # noqa: E501

        :param invoice_reference: The invoice_reference of this DesktopNodeLaunchSpec.  # noqa: E501
        :type invoice_reference: str
        """
        if (self.local_vars_configuration.client_side_validation and
                invoice_reference is not None and len(invoice_reference) > 100):
            raise ValueError("Invalid value for `invoice_reference`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                invoice_reference is not None and len(invoice_reference) < 1):
            raise ValueError("Invalid value for `invoice_reference`, length must be greater than or equal to `1`")  # noqa: E501

        self._invoice_reference = invoice_reference

    @property
    def data_path(self):
        """Gets the data_path of this DesktopNodeLaunchSpec.  # noqa: E501


        :return: The data_path of this DesktopNodeLaunchSpec.  # noqa: E501
        :rtype: DataSpec
        """
        return self._data_path

    @data_path.setter
    def data_path(self, data_path):
        """Sets the data_path of this DesktopNodeLaunchSpec.


        :param data_path: The data_path of this DesktopNodeLaunchSpec.  # noqa: E501
        :type data_path: DataSpec
        """
        if self.local_vars_configuration.client_side_validation and data_path is None:  # noqa: E501
            raise ValueError("Invalid value for `data_path`, must not be `None`")  # noqa: E501

        self._data_path = data_path

    @property
    def mount_type(self):
        """Gets the mount_type of this DesktopNodeLaunchSpec.  # noqa: E501

        How should the data folder be mounted to the desktop. Offline takes a copy of the data and will not be automatically synced back to the data store.  # noqa: E501

        :return: The mount_type of this DesktopNodeLaunchSpec.  # noqa: E501
        :rtype: str
        """
        return self._mount_type

    @mount_type.setter
    def mount_type(self, mount_type):
        """Sets the mount_type of this DesktopNodeLaunchSpec.

        How should the data folder be mounted to the desktop. Offline takes a copy of the data and will not be automatically synced back to the data store.  # noqa: E501

        :param mount_type: The mount_type of this DesktopNodeLaunchSpec.  # noqa: E501
        :type mount_type: str
        """
        if self.local_vars_configuration.client_side_validation and mount_type is None:  # noqa: E501
            raise ValueError("Invalid value for `mount_type`, must not be `None`")  # noqa: E501
        allowed_values = ["online", "offline"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and mount_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `mount_type` ({0}), must be one of {1}"  # noqa: E501
                .format(mount_type, allowed_values)
            )

        self._mount_type = mount_type

    @property
    def project(self):
        """Gets the project of this DesktopNodeLaunchSpec.  # noqa: E501

        Project ID to bill this desktop node against  # noqa: E501

        :return: The project of this DesktopNodeLaunchSpec.  # noqa: E501
        :rtype: int
        """
        return self._project

    @project.setter
    def project(self, project):
        """Sets the project of this DesktopNodeLaunchSpec.

        Project ID to bill this desktop node against  # noqa: E501

        :param project: The project of this DesktopNodeLaunchSpec.  # noqa: E501
        :type project: int
        """
        if (self.local_vars_configuration.client_side_validation and
                project is not None and project < -1):  # noqa: E501
            raise ValueError("Invalid value for `project`, must be a value greater than or equal to `-1`")  # noqa: E501

        self._project = project

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DesktopNodeLaunchSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DesktopNodeLaunchSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class DesktopNodeQuote(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'application_version': 'int',
        'node_type': 'int',
        'connection_type': 'int',
        'runtime': 'int'
    }

    attribute_map = {
        'application_version': 'application_version',
        'node_type': 'node_type',
        'connection_type': 'connection_type',
        'runtime': 'runtime'
    }

    def __init__(self, application_version=None, node_type=None, connection_type=None, runtime=None, local_vars_configuration=None):  # noqa: E501
        """DesktopNodeQuote - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._application_version = None
        self._node_type = None
        self._connection_type = None
        self._runtime = None
        self.discriminator = None

        self.application_version = application_version
        self.node_type = node_type
        self.connection_type = connection_type
        self.runtime = runtime

    @property
    def application_version(self):
        """Gets the application_version of this DesktopNodeQuote.  # noqa: E501

        ID of the application_version to launch. Valid values are obtained from the catalog/desktop/ endpoint  # noqa: E501

        :return: The application_version of this DesktopNodeQuote.  # noqa: E501
        :rtype: int
        """
        return self._application_version

    @application_version.setter
    def application_version(self, application_version):
        """Sets the application_version of this DesktopNodeQuote.

        ID of the application_version to launch. Valid values are obtained from the catalog/desktop/ endpoint  # noqa: E501

        :param application_version: The application_version of this DesktopNodeQuote.  # noqa: E501
        :type application_version: int
        """
        if self.local_vars_configuration.client_side_validation and application_version is None:  # noqa: E501
            raise ValueError("Invalid value for `application_version`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                application_version is not None and application_version < 1):  # noqa: E501
            raise ValueError("Invalid value for `application_version`, must be a value greater than or equal to `1`")  # noqa: E501

        self._application_version = application_version

    @property
    def node_type(self):
        """Gets the node_type of this DesktopNodeQuote.  # noqa: E501

        ID of the node_type. Valid values are obtained from the catalog/desktop/ endpoint  # noqa: E501

        :return: The node_type of this DesktopNodeQuote.  # noqa: E501
        :rtype: int
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """Sets the node_type of this DesktopNodeQuote.

        ID of the node_type. Valid values are obtained from the catalog/desktop/ endpoint  # noqa: E501

        :param node_type: The node_type of this DesktopNodeQuote.  # noqa: E501
        :type node_type: int
        """
        if self.local_vars_configuration.client_side_validation and node_type is None:  # noqa: E501
            raise ValueError("Invalid value for `node_type`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                node_type is not None and node_type < 1):  # noqa: E501
            raise ValueError("Invalid value for `node_type`, must be a value greater than or equal to `1`")  # noqa: E501

        self._node_type = node_type

    @property
    def connection_type(self):
        """Gets the connection_type of this DesktopNodeQuote.  # noqa: E501

        The connection type to use for the Desktop  # noqa: E501

        :return: The connection_type of this DesktopNodeQuote.  # noqa: E501
        :rtype: int
        """
        return self._connection_type

    @connection_type.setter
    def connection_type(self, connection_type):
        """Sets the connection_type of this DesktopNodeQuote.

        The connection type to use for the Desktop  # noqa: E501

        :param connection_type: The connection_type of this DesktopNodeQuote.  # noqa: E501
        :type connection_type: int
        """
        if self.local_vars_configuration.client_side_validation and connection_type is None:  # noqa: E501
            raise ValueError("Invalid value for `connection_type`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                connection_type is not None and connection_type < 1):  # noqa: E501
            raise ValueError("Invalid value for `connection_type`, must be a value greater than or equal to `1`")  # noqa: E501

        self._connection_type = connection_type

    @property
    def runtime(self):
        """Gets the runtime of this DesktopNodeQuote.  # noqa: E501

        Runtime in hours to run this desktop node for. This is the maximum runtime as the viz node can be stopped earlier and you will only be charged for the elapsed time  # noqa: E501

        :return: The runtime of this DesktopNodeQuote.  # noqa: E501
        :rtype: int
        """
        return self._runtime

    @runtime.setter
    def runtime(self, runtime):
        """Sets the runtime of this DesktopNodeQuote.

        Runtime in hours to run this desktop node for. This is the maximum runtime as the viz node can be stopped earlier and you will only be charged for the elapsed time  # noqa: E501

        :param runtime: The runtime of this DesktopNodeQuote.  # noqa: E501
        :type runtime: int
        """
        if self.local_vars_configuration.client_side_validation and runtime is None:  # noqa: E501
            raise ValueError("Invalid value for `runtime`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                runtime is not None and runtime < 1):  # noqa: E501
            raise ValueError("Invalid value for `runtime`, must be a value greater than or equal to `1`")  # noqa: E501

        self._runtime = runtime

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DesktopNodeQuote):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DesktopNodeQuote):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class ProjectDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pk': 'int',
        'project_id': 'str',
        'description': 'str',
        'closed': 'bool',
        'all_users': 'bool',
        'authorized_user_profiles': 'list[int]',
        'has_budget': 'bool',
        'spend_limit': 'SpendLimit',
        'current_spend': 'CurrentSpend'
    }

    attribute_map = {
        'pk': 'pk',
        'project_id': 'project_id',
        'description': 'description',
        'closed': 'closed',
        'all_users': 'all_users',
        'authorized_user_profiles': 'authorized_user_profiles',
        'has_budget': 'has_budget',
        'spend_limit': 'spend_limit',
        'current_spend': 'current_spend'
    }

    def __init__(self, pk=None, project_id=None, description=None, closed=None, all_users=None, authorized_user_profiles=None, has_budget=None, spend_limit=None, current_spend=None, local_vars_configuration=None):  # noqa: E501
        """ProjectDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pk = None
        self._project_id = None
        self._description = None
        self._closed = None
        self._all_users = None
        self._authorized_user_profiles = None
        self._has_budget = None
        self._spend_limit = None
        self._current_spend = None
        self.discriminator = None

        if pk is not None:
            self.pk = pk
        if project_id is not None:
            self.project_id = project_id
        self.description = description
        if closed is not None:
            self.closed = closed
        if all_users is not None:
            self.all_users = all_users
        if authorized_user_profiles is not None:
            self.authorized_user_profiles = authorized_user_profiles
        if has_budget is not None:
            self.has_budget = has_budget
        if spend_limit is not None:
            self.spend_limit = spend_limit
        if current_spend is not None:
            self.current_spend = current_spend

    @property
    def pk(self):
        """Gets the pk of this ProjectDetails.  # noqa: E501


        :return: The pk of this ProjectDetails.  # noqa: E501
        :rtype: int
        """
        return self._pk

    @pk.setter
    def pk(self, pk):
        """Sets the pk of this ProjectDetails.


        :param pk: The pk of this ProjectDetails.  # noqa: E501
        :type pk: int
        """

        self._pk = pk

    @property
    def project_id(self):
        """Gets the project_id of this ProjectDetails.  # noqa: E501


        :return: The project_id of this ProjectDetails.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ProjectDetails.


        :param project_id: The project_id of this ProjectDetails.  # noqa: E501
        :type project_id: str
        """
        if (self.local_vars_configuration.client_side_validation and
                project_id is not None and len(project_id) < 1):
            raise ValueError("Invalid value for `project_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._project_id = project_id

    @property
    def description(self):
        """Gets the description of this ProjectDetails.  # noqa: E501


        :return: The description of this ProjectDetails.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ProjectDetails.


        :param description: The description of this ProjectDetails.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def closed(self):
        """Gets the closed of this ProjectDetails.  # noqa: E501


        :return: The closed of this ProjectDetails.  # noqa: E501
        :rtype: bool
        """
        return self._closed

    @closed.setter
    def closed(self, closed):
        """Sets the closed of this ProjectDetails.


        :param closed: The closed of this ProjectDetails.  # noqa: E501
        :type closed: bool
        """

        self._closed = closed

    @property
    def all_users(self):
        """Gets the all_users of this ProjectDetails.  # noqa: E501


        :return: The all_users of this ProjectDetails.  # noqa: E501
        :rtype: bool
        """
        return self._all_users

    @all_users.setter
    def all_users(self, all_users):
        """Sets the all_users of this ProjectDetails.


        :param all_users: The all_users of this ProjectDetails.  # noqa: E501
        :type all_users: bool
        """

        self._all_users = all_users

    @property
    def authorized_user_profiles(self):
        """Gets the authorized_user_profiles of this ProjectDetails.  # noqa: E501


        :return: The authorized_user_profiles of this ProjectDetails.  # noqa: E501
        :rtype: list[int]
        """
        return self._authorized_user_profiles

    @authorized_user_profiles.setter
    def authorized_user_profiles(self, authorized_user_profiles):
        """Sets the authorized_user_profiles of this ProjectDetails.


        :param authorized_user_profiles: The authorized_user_profiles of this ProjectDetails.  # noqa: E501
        :type authorized_user_profiles: list[int]
        """

        self._authorized_user_profiles = authorized_user_profiles

    @property
    def has_budget(self):
        """Gets the has_budget of this ProjectDetails.  # noqa: E501


        :return: The has_budget of this ProjectDetails.  # noqa: E501
        :rtype: bool
        """
        return self._has_budget

    @has_budget.setter
    def has_budget(self, has_budget):
        """Sets the has_budget of this ProjectDetails.


        :param has_budget: The has_budget of this ProjectDetails.  # noqa: E501
        :type has_budget: bool
        """

        self._has_budget = has_budget

    @property
    def spend_limit(self):
        """Gets the spend_limit of this ProjectDetails.  # noqa: E501


        :return: The spend_limit of this ProjectDetails.  # noqa: E501
        :rtype: SpendLimit
        """
        return self._spend_limit

    @spend_limit.setter
    def spend_limit(self, spend_limit):
        """Sets the spend_limit of this ProjectDetails.


        :param spend_limit: The spend_limit of this ProjectDetails.  # noqa: E501
        :type spend_limit: SpendLimit
        """

        self._spend_limit = spend_limit

    @property
    def current_spend(self):
        """Gets the current_spend of this ProjectDetails.  # noqa: E501


        :return: The current_spend of this ProjectDetails.  # noqa: E501
        :rtype: CurrentSpend
        """
        return self._current_spend

    @current_spend.setter
    def current_spend(self, current_spend):
        """Sets the current_spend of this ProjectDetails.


        :param current_spend: The current_spend of this ProjectDetails.  # noqa: E501
        :type current_spend: CurrentSpend
        """

        self._current_spend = current_spend

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProjectDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class ClusterNodeConfig(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'accelerator': 'AcceleratorConfig',
        'cpus': 'int',
        'cpu_generation': 'str',
        'cores_per_cpu': 'int',
        'threads_per_core': 'int',
        'memory': 'str'
    }

    attribute_map = {
        'accelerator': 'accelerator',
        'cpus': 'cpus',
        'cpu_generation': 'cpu_generation',
        'cores_per_cpu': 'cores_per_cpu',
        'threads_per_core': 'threads_per_core',
        'memory': 'memory'
    }

    def __init__(self, accelerator=None, cpus=None, cpu_generation=None, cores_per_cpu=None, threads_per_core=None, memory=None, local_vars_configuration=None):  # noqa: E501
        """ClusterNodeConfig - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._accelerator = None
        self._cpus = None
        self._cpu_generation = None
        self._cores_per_cpu = None
        self._threads_per_core = None
        self._memory = None
        self.discriminator = None

        self.accelerator = accelerator
        if cpus is not None:
            self.cpus = cpus
        if cpu_generation is not None:
            self.cpu_generation = cpu_generation
        if cores_per_cpu is not None:
            self.cores_per_cpu = cores_per_cpu
        if threads_per_core is not None:
            self.threads_per_core = threads_per_core
        if memory is not None:
            self.memory = memory

    @property
    def accelerator(self):
        """Gets the accelerator of this ClusterNodeConfig.  # noqa: E501


        :return: The accelerator of this ClusterNodeConfig.  # noqa: E501
        :rtype: AcceleratorConfig
        """
        return self._accelerator

    @accelerator.setter
    def accelerator(self, accelerator):
        """Sets the accelerator of this ClusterNodeConfig.


        :param accelerator: The accelerator of this ClusterNodeConfig.  # noqa: E501
        :type accelerator: AcceleratorConfig
        """

        self._accelerator = accelerator

    @property
    def cpus(self):
        """Gets the cpus of this ClusterNodeConfig.  # noqa: E501


        :return: The cpus of this ClusterNodeConfig.  # noqa: E501
        :rtype: int
        """
        return self._cpus

    @cpus.setter
    def cpus(self, cpus):
        """Sets the cpus of this ClusterNodeConfig.


        :param cpus: The cpus of this ClusterNodeConfig.  # noqa: E501
        :type cpus: int
        """
        if (self.local_vars_configuration.client_side_validation and
                cpus is not None and cpus > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `cpus`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cpus is not None and cpus < 1):  # noqa: E501
            raise ValueError("Invalid value for `cpus`, must be a value greater than or equal to `1`")  # noqa: E501

        self._cpus = cpus

    @property
    def cpu_generation(self):
        """Gets the cpu_generation of this ClusterNodeConfig.  # noqa: E501


        :return: The cpu_generation of this ClusterNodeConfig.  # noqa: E501
        :rtype: str
        """
        return self._cpu_generation

    @cpu_generation.setter
    def cpu_generation(self, cpu_generation):
        """Sets the cpu_generation of this ClusterNodeConfig.


        :param cpu_generation: The cpu_generation of this ClusterNodeConfig.  # noqa: E501
        :type cpu_generation: str
        """
        if (self.local_vars_configuration.client_side_validation and
                cpu_generation is not None and len(cpu_generation) > 255):
            raise ValueError("Invalid value for `cpu_generation`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cpu_generation is not None and len(cpu_generation) < 1):
            raise ValueError("Invalid value for `cpu_generation`, length must be greater than or equal to `1`")  # noqa: E501

        self._cpu_generation = cpu_generation

    @property
    def cores_per_cpu(self):
        """Gets the cores_per_cpu of this ClusterNodeConfig.  # noqa: E501


        :return: The cores_per_cpu of this ClusterNodeConfig.  # noqa: E501
        :rtype: int
        """
        return self._cores_per_cpu

    @cores_per_cpu.setter
    def cores_per_cpu(self, cores_per_cpu):
        """Sets the cores_per_cpu of this ClusterNodeConfig.


        :param cores_per_cpu: The cores_per_cpu of this ClusterNodeConfig.  # noqa: E501
        :type cores_per_cpu: int
        """
        if (self.local_vars_configuration.client_side_validation and
                cores_per_cpu is not None and cores_per_cpu > 2147483647):  # noqa: E501
            raise ValueError("Invalid value for `cores_per_cpu`, must be a value less than or equal to `2147483647`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cores_per_cpu is not None and cores_per_cpu < 1):  # noqa: E501
            raise ValueError("Invalid value for `cores_per_cpu`, must be a value greater than or equal to `1`")  # noqa: E501

        self._cores_per_cpu = cores_per_cpu

    @property
    def threads_per_core(self):
        """Gets the threads_per_core of this ClusterNodeConfig.  # noqa: E501


        :return: The threads_per_core of this ClusterNodeConfig.  # noqa: E501
        :rtype: int
        """
        return self._threads_per_core

    @threads_per_core.setter
    def threads_per_core(self, threads_per_core):
        """Sets the threads_per_core of this ClusterNodeConfig.


        :param threads_per_core: The threads_per_core of this ClusterNodeConfig.  # noqa: E501
        :type threads_per_core: int
        """
        if (self.local_vars_configuration.client_side_validation and
                threads_per_core is not None and threads_per_core < 1):  # noqa: E501
            raise ValueError("Invalid value for `threads_per_core`, must be a value greater than or equal to `1`")  # noqa: E501

        self._threads_per_core = threads_per_core

    @property
    def memory(self):
        """Gets the memory of this ClusterNodeConfig.  # noqa: E501


        :return: The memory of this ClusterNodeConfig.  # noqa: E501
        :rtype: str
        """
        return self._memory

    @memory.setter
    def memory(self, memory):
        """Sets the memory of this ClusterNodeConfig.


        :param memory: The memory of this ClusterNodeConfig.  # noqa: E501
        :type memory: str
        """

        self._memory = memory

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClusterNodeConfig):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClusterNodeConfig):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class JobConfiguration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'upload': 'list[str]',
        'overwrite_existing': 'bool',
        'data_sync_interval': 'int'
    }

    attribute_map = {
        'upload': 'upload',
        'overwrite_existing': 'overwrite_existing',
        'data_sync_interval': 'data_sync_interval'
    }

    def __init__(self, upload=None, overwrite_existing=True, data_sync_interval=None, local_vars_configuration=None):  # noqa: E501
        """JobConfiguration - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._upload = None
        self._overwrite_existing = None
        self._data_sync_interval = None
        self.discriminator = None

        if upload is not None:
            self.upload = upload
        if overwrite_existing is not None:
            self.overwrite_existing = overwrite_existing
        if data_sync_interval is not None:
            self.data_sync_interval = data_sync_interval

    @property
    def upload(self):
        """Gets the upload of this JobConfiguration.  # noqa: E501

        When should data be uploaded?  # noqa: E501

        :return: The upload of this JobConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._upload

    @upload.setter
    def upload(self, upload):
        """Sets the upload of this JobConfiguration.

        When should data be uploaded?  # noqa: E501

        :param upload: The upload of this JobConfiguration.  # noqa: E501
        :type upload: list[str]
        """
        allowed_values = ["complete", "failure", "cancel"]  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                not set(upload).issubset(set(allowed_values))):  # noqa: E501
            raise ValueError(
                "Invalid values for `upload` [{0}], must be a subset of [{1}]"  # noqa: E501
                .format(", ".join(map(str, set(upload) - set(allowed_values))),  # noqa: E501
                        ", ".join(map(str, allowed_values)))
            )

        self._upload = upload

    @property
    def overwrite_existing(self):
        """Gets the overwrite_existing of this JobConfiguration.  # noqa: E501

        Should uploads overwrite existing data files?  # noqa: E501

        :return: The overwrite_existing of this JobConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._overwrite_existing

    @overwrite_existing.setter
    def overwrite_existing(self, overwrite_existing):
        """Sets the overwrite_existing of this JobConfiguration.

        Should uploads overwrite existing data files?  # noqa: E501

        :param overwrite_existing: The overwrite_existing of this JobConfiguration.  # noqa: E501
        :type overwrite_existing: bool
        """

        self._overwrite_existing = overwrite_existing

    @property
    def data_sync_interval(self):
        """Gets the data_sync_interval of this JobConfiguration.  # noqa: E501

        How frequently should the data be uploaded back to the EPIC data store?  # noqa: E501

        :return: The data_sync_interval of this JobConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._data_sync_interval

    @data_sync_interval.setter
    def data_sync_interval(self, data_sync_interval):
        """Sets the data_sync_interval of this JobConfiguration.

        How frequently should the data be uploaded back to the EPIC data store?  # noqa: E501

        :param data_sync_interval: The data_sync_interval of this JobConfiguration.  # noqa: E501
        :type data_sync_interval: int
        """
        if (self.local_vars_configuration.client_side_validation and
                data_sync_interval is not None and data_sync_interval < 0):  # noqa: E501
            raise ValueError("Invalid value for `data_sync_interval`, must be a value greater than or equal to `0`")  # noqa: E501

        self._data_sync_interval = data_sync_interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JobConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class TeamDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'number_of_members': 'int',
        'user_role': 'str',
        'members': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'number_of_members': 'number_of_members',
        'user_role': 'user_role',
        'members': 'members'
    }

    def __init__(self, id=None, name=None, number_of_members=None, user_role=None, members=None, local_vars_configuration=None):  # noqa: E501
        """TeamDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._number_of_members = None
        self._user_role = None
        self._members = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if number_of_members is not None:
            self.number_of_members = number_of_members
        if user_role is not None:
            self.user_role = user_role
        if members is not None:
            self.members = members

    @property
    def id(self):
        """Gets the id of this TeamDetails.  # noqa: E501

        ID for this team  # noqa: E501

        :return: The id of this TeamDetails.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TeamDetails.

        ID for this team  # noqa: E501

        :param id: The id of this TeamDetails.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this TeamDetails.  # noqa: E501

        Name of this team  # noqa: E501

        :return: The name of this TeamDetails.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TeamDetails.

        Name of this team  # noqa: E501

        :param name: The name of this TeamDetails.  # noqa: E501
        :type name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def number_of_members(self):
        """Gets the number_of_members of this TeamDetails.  # noqa: E501

        Number of members in this team  # noqa: E501

        :return: The number_of_members of this TeamDetails.  # noqa: E501
        :rtype: int
        """
        return self._number_of_members

    @number_of_members.setter
    def number_of_members(self, number_of_members):
        """Sets the number_of_members of this TeamDetails.

        Number of members in this team  # noqa: E501

        :param number_of_members: The number_of_members of this TeamDetails.  # noqa: E501
        :type number_of_members: int
        """

        self._number_of_members = number_of_members

    @property
    def user_role(self):
        """Gets the user_role of this TeamDetails.  # noqa: E501

        Your role in this team  # noqa: E501

        :return: The user_role of this TeamDetails.  # noqa: E501
        :rtype: str
        """
        return self._user_role

    @user_role.setter
    def user_role(self, user_role):
        """Sets the user_role of this TeamDetails.

        Your role in this team  # noqa: E501

        :param user_role: The user_role of this TeamDetails.  # noqa: E501
        :type user_role: str
        """

        self._user_role = user_role

    @property
    def members(self):
        """Gets the members of this TeamDetails.  # noqa: E501

        List of user ids and roles for members of this team  # noqa: E501

        :return: The members of this TeamDetails.  # noqa: E501
        :rtype: str
        """
        return self._members

    @members.setter
    def members(self, members):
        """Sets the members of this TeamDetails.

        List of user ids and roles for members of this team  # noqa: E501

        :param members: The members of this TeamDetails.  # noqa: E501
        :type members: str
        """

        self._members = members

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TeamDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TeamDetails):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from epiccore.api.billing_api import BillingApi
from epiccore.api.catalog_api import CatalogApi
from epiccore.api.data_api import DataApi
from epiccore.api.desktop_api import DesktopApi
from epiccore.api.job_api import JobApi
from epiccore.api.jobauth_api import JobauthApi
from epiccore.api.jobstep_api import JobstepApi
from epiccore.api.licenses_api import LicensesApi
from epiccore.api.profile_api import ProfileApi
from epiccore.api.projects_api import ProjectsApi
from epiccore.api.teams_api import TeamsApi



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class Limits(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'limits': 'list[Limit]',
        'max_limit': 'MaxLimit',
        'max_limit_str': 'str',
        'total': 'Total',
        'total_str': 'str'
    }

    attribute_map = {
        'limits': 'limits',
        'max_limit': 'max_limit',
        'max_limit_str': 'max_limit_str',
        'total': 'total',
        'total_str': 'total_str'
    }

    def __init__(self, limits=None, max_limit=None, max_limit_str=None, total=None, total_str=None, local_vars_configuration=None):  # noqa: E501
        """Limits - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._limits = None
        self._max_limit = None
        self._max_limit_str = None
        self._total = None
        self._total_str = None
        self.discriminator = None

        self.limits = limits
        if max_limit is not None:
            self.max_limit = max_limit
        if max_limit_str is not None:
            self.max_limit_str = max_limit_str
        if total is not None:
            self.total = total
        if total_str is not None:
            self.total_str = total_str

    @property
    def limits(self):
        """Gets the limits of this Limits.  # noqa: E501

        List of limits for all teams linked to the current user's billing profile  # noqa: E501

        :return: The limits of this Limits.  # noqa: E501
        :rtype: list[Limit]
        """
        return self._limits

    @limits.setter
    def limits(self, limits):
        """Sets the limits of this Limits.

        List of limits for all teams linked to the current user's billing profile  # noqa: E501

        :param limits: The limits of this Limits.  # noqa: E501
        :type limits: list[Limit]
        """
        if self.local_vars_configuration.client_side_validation and limits is None:  # noqa: E501
            raise ValueError("Invalid value for `limits`, must not be `None`")  # noqa: E501

        self._limits = limits

    @property
    def max_limit(self):
        """Gets the max_limit of this Limits.  # noqa: E501


        :return: The max_limit of this Limits.  # noqa: E501
        :rtype: MaxLimit
        """
        return self._max_limit

    @max_limit.setter
    def max_limit(self, max_limit):
        """Sets the max_limit of this Limits.


        :param max_limit: The max_limit of this Limits.  # noqa: E501
        :type max_limit: MaxLimit
        """

        self._max_limit = max_limit

    @property
    def max_limit_str(self):
        """Gets the max_limit_str of this Limits.  # noqa: E501

        Maximum monthly spend limit for the current user's billing profile as a string in user's display currency  # noqa: E501

        :return: The max_limit_str of this Limits.  # noqa: E501
        :rtype: str
        """
        return self._max_limit_str

    @max_limit_str.setter
    def max_limit_str(self, max_limit_str):
        """Sets the max_limit_str of this Limits.

        Maximum monthly spend limit for the current user's billing profile as a string in user's display currency  # noqa: E501

        :param max_limit_str: The max_limit_str of this Limits.  # noqa: E501
        :type max_limit_str: str
        """
        if (self.local_vars_configuration.client_side_validation and
                max_limit_str is not None and len(max_limit_str) > 30):
            raise ValueError("Invalid value for `max_limit_str`, length must be less than or equal to `30`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                max_limit_str is not None and len(max_limit_str) < 1):
            raise ValueError("Invalid value for `max_limit_str`, length must be greater than or equal to `1`")  # noqa: E501

        self._max_limit_str = max_limit_str

    @property
    def total(self):
        """Gets the total of this Limits.  # noqa: E501


        :return: The total of this Limits.  # noqa: E501
        :rtype: Total
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this Limits.


        :param total: The total of this Limits.  # noqa: E501
        :type total: Total
        """

        self._total = total

    @property
    def total_str(self):
        """Gets the total_str of this Limits.  # noqa: E501

        Current total monthly spend limit as a string  # noqa: E501

        :return: The total_str of this Limits.  # noqa: E501
        :rtype: str
        """
        return self._total_str

    @total_str.setter
    def total_str(self, total_str):
        """Sets the total_str of this Limits.

        Current total monthly spend limit as a string  # noqa: E501

        :param total_str: The total_str of this Limits.  # noqa: E501
        :type total_str: str
        """
        if (self.local_vars_configuration.client_side_validation and
                total_str is not None and len(total_str) > 30):
            raise ValueError("Invalid value for `total_str`, length must be less than or equal to `30`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                total_str is not None and len(total_str) < 1):
            raise ValueError("Invalid value for `total_str`, length must be greater than or equal to `1`")  # noqa: E501

        self._total_str = total_str

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Limits):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Limits):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    EPIC API

    REST API for interacting with EPIC (https://epic.zenotech.com) services. <br />                             Please note this API is in BETA and does not yet contain                             all EPIC functionality.  # noqa: E501

    The version of the OpenAPI document: v2
    Contact: support@zenotech.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from epiccore.configuration import Configuration


class DesktopInstance(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'status': 'str',
        'connection_type': 'DesktopNodeConnectionType',
        'connection_string': 'str',
        'application': 'DesktopNodeApplicationVersionSummary',
        'launched_by': 'str',
        'team': 'str',
        'created': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'connection_type': 'connection_type',
        'connection_string': 'connection_string',
        'application': 'application',
        'launched_by': 'launched_by',
        'team': 'team',
        'created': 'created'
    }

    def __init__(self, id=None, status=None, connection_type=None, connection_string=None, application=None, launched_by=None, team=None, created=None, local_vars_configuration=None):  # noqa: E501
        """DesktopInstance - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._status = None
        self._connection_type = None
        self._connection_string = None
        self._application = None
        self._launched_by = None
        self._team = None
        self._created = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        self.connection_type = connection_type
        self.connection_string = connection_string
        if application is not None:
            self.application = application
        if launched_by is not None:
            self.launched_by = launched_by
        self.team = team
        if created is not None:
            self.created = created

    @property
    def id(self):
        """Gets the id of this DesktopInstance.  # noqa: E501


        :return: The id of this DesktopInstance.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DesktopInstance.


        :param id: The id of this DesktopInstance.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def status(self):
        """Gets the status of this DesktopInstance.  # noqa: E501

        Current desktop status  # noqa: E501

        :return: The status of this DesktopInstance.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DesktopInstance.

        Current desktop status  # noqa: E501

        :param status: The status of this DesktopInstance.  # noqa: E501
        :type status: str
        """

        self._status = status

    @property
    def connection_type(self):
        """Gets the connection_type of this DesktopInstance.  # noqa: E501


        :return: The connection_type of this DesktopInstance.  # noqa: E501
        :rtype: DesktopNodeConnectionType
        """
        return self._connection_type

    @connection_type.setter
    def connection_type(self, connection_type):
        """Sets the connection_type of this DesktopInstance.


        :param connection_type: The connection_type of this DesktopInstance.  # noqa: E501
        :type connection_type: DesktopNodeConnectionType
        """
        if self.local_vars_configuration.client_side_validation and connection_type is None:  # noqa: E501
            raise ValueError("Invalid value for `connection_type`, must not be `None`")  # noqa: E501

        self._connection_type = connection_type

    @property
    def connection_string(self):
        """Gets the connection_string of this DesktopInstance.  # noqa: E501

        The URL or hostname of the desktop  # noqa: E501

        :return: The connection_string of this DesktopInstance.  # noqa: E501
        :rtype: str
        """
        return self._connection_string

    @connection_string.setter
    def connection_string(self, connection_string):
        """Sets the connection_string of this DesktopInstance.

        The URL or hostname of the desktop  # noqa: E501

        :param connection_string: The connection_string of this DesktopInstance.  # noqa: E501
        :type connection_string: str
        """

        self._connection_string = connection_string

    @property
    def application(self):
        """Gets the application of this DesktopInstance.  # noqa: E501


        :return: The application of this DesktopInstance.  # noqa: E501
        :rtype: DesktopNodeApplicationVersionSummary
        """
        return self._application

    @application.setter
    def application(self, application):
        """Sets the application of this DesktopInstance.


        :param application: The application of this DesktopInstance.  # noqa: E501
        :type application: DesktopNodeApplicationVersionSummary
        """

        self._application = application

    @property
    def launched_by(self):
        """Gets the launched_by of this DesktopInstance.  # noqa: E501

        Full name of user that launched the desktop  # noqa: E501

        :return: The launched_by of this DesktopInstance.  # noqa: E501
        :rtype: str
        """
        return self._launched_by

    @launched_by.setter
    def launched_by(self, launched_by):
        """Sets the launched_by of this DesktopInstance.

        Full name of user that launched the desktop  # noqa: E501

        :param launched_by: The launched_by of this DesktopInstance.  # noqa: E501
        :type launched_by: str
        """

        self._launched_by = launched_by

    @property
    def team(self):
        """Gets the team of this DesktopInstance.  # noqa: E501

        ID of the active Team for the desktop  # noqa: E501

        :return: The team of this DesktopInstance.  # noqa: E501
        :rtype: str
        """
        return self._team

    @team.setter
    def team(self, team):
        """Sets the team of this DesktopInstance.

        ID of the active Team for the desktop  # noqa: E501

        :param team: The team of this DesktopInstance.  # noqa: E501
        :type team: str
        """

        self._team = team

    @property
    def created(self):
        """Gets the created of this DesktopInstance.  # noqa: E501


        :return: The created of this DesktopInstance.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this DesktopInstance.


        :param created: The created of this DesktopInstance.  # noqa: E501
        :type created: datetime
        """

        self._created = created

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DesktopInstance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DesktopInstance):
            return True

        return self.to_dict() != other.to_dict()
